@@ -1,10 +1,13 @@
 """Blackcap User PUT route schemas."""
 
-from typing import Optional
+from typing import List, Optional
 
 from pydantic import BaseModel
 from pydantic.types import UUID4
 
+from blackcap.schemas.api.common import ResponseSchema
+from blackcap.schemas.user import User
+
 
 class UserUpdate(BaseModel):
     """Schema to parse update user requests."""
@@ -13,3 +16,9 @@ class UserUpdate(BaseModel):
     name: Optional[str]
     email: Optional[str]
     organisation: Optional[str]
+
+
+class UserPUTResponse(ResponseSchema):
+    """User PUT response schema."""
+
+    items: List[User] = []
